<!-- markdownlint-disable line-length -->

# StepUp RepRep

[![release](https://github.com/reproducible-reporting/stepup-reprep/actions/workflows/release.yaml/badge.svg)](https://github.com/reproducible-reporting/stepup-reprep/actions/workflows/release.yaml)
[![pytest](https://github.com/reproducible-reporting/stepup-reprep/actions/workflows/pytest.yaml/badge.svg)](https://github.com/reproducible-reporting/stepup-reprep/actions/workflows/pytest.yaml)
[![mkdocs](https://github.com/reproducible-reporting/stepup-reprep/actions/workflows/mkdocs.yaml/badge.svg)](https://github.com/reproducible-reporting/stepup-reprep/actions/workflows/mkdocs.yaml)
[![PyPI Version](https://img.shields.io/pypi/v/stepup-reprep)](https://pypi.org/project/stepup-reprep/)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/stepup-reprep)
![GPL-3 License](https://img.shields.io/github/license/reproducible-reporting/stepup-reprep)
[![CodeFactor](https://www.codefactor.io/repository/github/reproducible-reporting/stepup-reprep/badge)](https://www.codefactor.io/repository/github/reproducible-reporting/stepup-reprep)

StepUp RepRep is the [StepUp](https://github.com/reproducible-reporting/stepup-core) extension for [Reproducible Reporting](https://github.com/reproducible-reporting).

For more information, consult the [documentation](http://reproducible-reporting.github.io/stepup-reprep).

A screen recording for a quick visual impression of StepUp RepRep in action:

[![asciicast](https://asciinema.org/a/718835.svg)](https://asciinema.org/a/718835)
